@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ox-bb" "0.0.2"
+(define-package "ox-bb" "20240907.1042"
   "BBCode Back-End for Org Export Engine."
   '((emacs "24.4")
     (org   "8.0"))
